@@ -7,7 +7,7 @@ use WWW::Leech::Parser;
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '0.04';
+    $VERSION     = '0.05';
     @ISA         = qw(Exporter);
     @EXPORT      = qw();
     @EXPORT_OK   = qw();
@@ -32,6 +32,14 @@ sub new{
 			return shift();
 		}
 	}
+	if(!$this->{'error_handler'}){
+		$this->{'error_handler'} = sub {
+			my $this = shift;
+			my $item = shift;
+			my $err = shift;
+			die $err;
+		}
+	}
 	
 	return $this;
 }
@@ -84,10 +92,21 @@ sub leech{
 		
 			$this->log("\tGetting item (".sprintf("%0${ll}d",$i)."/$llength): $_ ");
 
-			my $item = $this->{'parser'}->parse($this->_get($_));
-			$item->{'_url'} = $_->as_string;
+			my $str = $this->_get($_);
+
+			my $item = {'_url' => $_->as_string };
+
+			# try to parse content
+			eval{
+				$item = $this->{'parser'}->parse($str);
+			};
+
+			if($@){
+				$this->{'error_handler'}->($item,$this,$@);
+			} else {
+				$this->{'processor'}->($item,$this);
+			}
 
-			$this->{'processor'}->($item,$this);
 
 			return if($this->{'_stop_flag'});
 		}
@@ -210,6 +229,15 @@ WWW::Leech::Walker - small web content grabbing framework
 
 		# ... process grabbed data
 
+  	},
+
+  	error_handler => sub {
+		my $item = shift;
+		my $walker_obj = shift;
+		my $error_text = shift;
+
+		# ... handle error
+
   	}
   });
 
@@ -274,6 +302,10 @@ This callback is launched after the individual item is parsed and converted to a
 
 This optional callback is launched after any page was retrieved but before parsing started. Walker expects it to return scalar.
 
+=item error_handler
+
+Walker dies with an error message if something goes wrong while parsing. Providing this optional callback allows caller to handle such errors. Skip page with broken html for example.
+
 =item next_page_link_post_process
 
 This optional callback allows user to alter next page url. Usually these urls look like 'http://example.tld/list?page=2' and no changes needed there. But sometimes such links are javascript calls like 'javascript:gotoPageNumber(2)'. The source url is passed as is before walker absolutizes it. Walker passes current page url as a third agument - this may be usefull for links like 'javascript:gotoNextPage()'
